import { login, logout, getInfo, getSiteInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'

const user = {
  state: {
    token: getToken(),
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    setGlobalState: null,
    getGlobalState: null,
    deptId: '',
    userType: '',
    siteConfig: {},
    deptLevel: ''
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_DEPTID: (state, deptId) => {
      state.deptId = deptId
    },
    SET_CHANGE: (state, setGlobalState) => {
      state.setGlobalState = setGlobalState
    },
    SET_GOLBALSTATE: (state, getGlobalState) => {
      state.getGlobalState = getGlobalState
    },
    SET_USER_TYPE: (state, userType) => {
      state.userType = userType
    },
    SET_SITE_CONFIG: (state, microChange) => {
      state.siteConfig = microChange
    },
    SET_DEPTLEVEL: (state, deptLevel) => {
      state.deptLevel = deptLevel
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const code = userInfo.code
      const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid).then(res => {
          setToken(res.token)
          commit('SET_TOKEN', res.token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          const user = res.user
          const avatar = (user.avatar === '' || user.avatar == null) ? require('@/assets/images/profile.jpg') : process.env.VUE_APP_BASE_API + user.avatar
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          commit('SET_NAME', user.nickName)
          commit('SET_DEPTID', user.deptId)
          commit('SET_DEPTLEVEL', user.dept.level)
          commit('SET_USER_TYPE', user.userType)
          commit('SET_AVATAR', avatar)
          // 获取站点基础配置 dept.level是1代表平台 平台type传2 hospitalId是医院传的
          const temp = {
            type: user.dept.level === '1' ? '2' : null,
            hospitalId: user.dept.level === '1' ? null : user.deptId
          }
          getSiteInfo(temp).then(siteInfo => {
            // user.dept.level = 1 为平台; 2 为医院
            let siteConfig = {}
            if (user.dept.level === '2') {
              if (siteInfo.rows.length !== 0) {
                siteInfo.rows.forEach(item => {
                  siteConfig[item.key] = JSON.parse(item.content)
                })
              }
            } else if (user.dept.level === '1') {
              if (siteInfo.rows.length !== 0) {
                siteConfig = JSON.parse(siteInfo.rows[0].content)
              }
            }
            commit('SET_SITE_CONFIG', siteConfig)
          })
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          removeToken()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    }
  }
}

export default user
